@@ -58,7 +58,7 @@ gof.hergm <- function(object,
 
   # Simulated networks
   object.hergm <- simulate.hergm(object, verbose=verbose, sample_size = sample_size)
-  output <- summary_sample_network(edgelists=object.hergm$edgelist, sample_size=sample_size, directed=directed, n=n)
+  output <- summary_sample_network(edgelists=object.hergm$edgelist, sample_size=sample_size, directed=directed, n)
 
   # Goodness-of-fit plots
   par(mfrow = c(2, 3))
