@@ -18,7 +18,8 @@
 #                                                                         # 
 ###########################################################################
 
-summary.hergm <- function(object, ...)
+summary.hergm <- function(object,
+                          ...)
 {
   if (object$simulate == FALSE) 
     {
